Examples
=========

In this section, we provide simple and practical examples on how to use
the different subpackages of the ``pyrfu`` package.

.. toctree::
    :maxdepth: 1

    examples/00_overview/quick-overview.ipynb
    examples/01_mms/example_mms_b_e_j.ipynb
    examples/01_mms/example_mms_ebfields.ipynb
    examples/01_mms/example_mms_edr_signatures.ipynb
    examples/01_mms/example_mms_eis.ipynb
    examples/01_mms/example_mms_electron_psd.ipynb
    examples/01_mms/example_mms_feeps.ipynb
    examples/01_mms/example_mms_hpca.ipynb
    examples/01_mms/example_mms_ohmslaw.ipynb
    examples/01_mms/example_mms_particle_deflux.ipynb
    examples/01_mms/example_mms_particle_distributions.ipynb
    examples/01_mms/example_mms_particle_pad.ipynb
    examples/01_mms/example_mms_reduced_ion_dist.ipynb
    examples/01_mms/example_mms_reduced_electron_dist.ipynb
    examples/01_mms/example_mms_polarizationanalysis.ipynb
    examples/01_mms/example_mms_walen_test.ipynb
    examples/02_dispersion/example_dispersion_one_fluid.ipynb

